# indexedzodb

A simple, indexed model layer over ZODB.

This code is definitely pre-alpha, very experimental.

It is an attempt to implement a simple model class over ZODB with a basic indexing and query system.  Proper usage examples to follow.

Install with ```pip install indexedzodb```

*NOTE* Version 0.0.4 introduces a backwards incompatible change that requires a new database.